function [Q,chi,h,p]=Cochran(x,rad,alpha)
% funkce provadi Cochranuv test autokorelace 
% vstupni parametry:
% x - vektor realizaci
% rad - nejvyssi rad autokorelace
% alpha - hladina vyznamnosti
% vystupni parametry:
% Q - hodnota testove tatistiky
% chi - kriticka hodnota
% h zamitnuti (1)/nezamitnuti (0) nulove hypotezy
% p-hodnota testu

n=size(x,1);
if rad>n/4
    error('Rad autokorelace je prilis velky')
end;
    
Q=0;
for i=1:rad
    [r,p]=corrcoef(x(1:n-i),x(i+1:n));
    Q=Q+r(1,2)^2;
end;
Q=n*Q;
chi=chi2inv((1-alpha),rad);
if Q<chi 
    h=0;
else
    h=1;
end;
p=1-chi2cdf(Q,rad)
